@@ -1,8 +1,13 @@
-getNormalizedData=function(model,data){
+getNormalizedData=function(model,data,controls=NULL){
 	dd=data
-	dd$pred=predict(model,type="terms",marginal=~sample)
+	if (!is.null(controls)) {
+		dd=dd[!(dd$gene %in% controls),]
+	}
+	prr=predict(model,type="terms",marginal=~sample)
+	dd$pred=prr[1:nrow(dd)]
 	predicted=c()
 	for (g in unique(dd$gene)) {
+			if (g %in% controls) { next }
 			gs=c();coo=c()
 			for(s in unique(dd$sample)) {
 				gs=append(gs,dd$pred[dd$gene==g & dd$sample==s][1]/log(2))
@@ -16,4 +21,4 @@ getNormalizedData=function(model,data){
 	row.names(predicted)= unique(dd$sample)
 	row.names(conditions)= unique(dd$sample)
 	return(list("normData"=predicted,"conditions"=conditions))
-}
\ No newline at end of file
+}
